## 1.3.1 (2026-02-16)

### Bug fixes

Fix parsing of blocks after nested pseudo-class selectors.

## 1.3.0 (2025-07-07)

### Bug fixes

Values wrapped in brackets can now contain more types of tokens.

Properly support hex escapes in identifiers.

Support variable names as callees in call expressions.

### New features

Add support for `@scope` syntax.

Add support for `if` notation.

## 1.2.1 (2025-05-15)

### Bug fixes

Fix parsing of `*` selectors in descendant positions.

## 1.2.0 (2025-05-12)

### Bug fixes

Allow @ keywords to start with a dash, since prefixed ones exist.

Bump the dependency on @lezer/lr to a version that supports local token groups. Also bump @lezer/generator dependency

### New features

Add support for range queries.

`@import` statements now support `layer` syntax.

Support relative versions of the `+`, `>`, and `~` selectors, which omit the left-hand selector. Allow @-keywords to start with a dash

## 1.1.11 (2025-03-24)

### Bug fixes

Accept trailing commas in argument lists.

## 1.1.10 (2025-01-24)

### Bug fixes

Emit a node for class selector dots.

## 1.1.9 (2024-09-10)

### Bug fixes

Allow `url()` values to be empty.

Don't generate a parse error when declarations don't have a value.

## 1.1.8 (2024-02-19)

### Bug fixes

Follow the standard, allowing digits in unit identifiers.

## 1.1.7 (2024-01-08)

### Bug fixes

Correctly parse properties with a space before the colon.

## 1.1.6 (2024-01-01)

### Bug fixes

Add support for bracketed grid line names.

## 1.1.5 (2023-12-28)

### Bug fixes

Tag comments and strings as isolating for the purpose of bidirectional text.

## 1.1.4 (2023-11-09)

### Bug fixes

Fix parsing of `&` selectors in descendant selectors.

Allow identifiers to contain backslash escapes.

## 1.1.3 (2023-07-03)

### Bug fixes

Comments are now parsed to end of file if no closing `*/` is found.

Make the package work with new TS resolution styles.

## 1.1.2 (2023-05-15)

### Bug fixes

Make keyframe selector parsing more flexible to support timeline ranges.

Allow multiple comma-separated keyframe selectors per keyframe.

## 1.1.1 (2022-12-02)

### Bug fixes

The `Styles` top rule now also recognizes nested rules.

## 1.1.0 (2022-11-25)

### Bug fixes

Don't emit an error node when the input is empty. Export a Styles top-level rule for parsing lists of properties

### New features

The new `Styles` top-level rule can be used to parse semicolon-separated lists of properties.

## 1.0.1 (2022-10-10)

### Bug fixes

Add support for the `is`, `where`, `host-context`, `nth-last-of-type`, and `nth-of-type` pseudo classes.

Apply a consistent highlighting tag (`definitionKeyword`) to all @ keywords.

## 1.0.0 (2022-06-06)

### New features

First stable version.

## 0.16.0 (2022-04-20)

### Breaking changes

Move to 0.16 serialized parser format.

### New features

The parser now includes syntax highlighting information in its node types.

## 0.15.2 (2021-09-24)

### Bug fixes

Distinguish between variable names and other names.

Fix the name of nodes for the `selector` keyword (which by accident was `callee` before).

## 0.15.1 (2021-08-31)

### Bug fixes

Fix parsing of selector arguments to pseudo selectors.

## 0.15.0 (2021-08-11)

### Breaking changes

The module's name changed from `lezer-css` to `@lezer/css`.

Upgrade to the 0.15.0 lezer interfaces.

## 0.13.1 (2020-12-04)

### Bug fixes

Fix versions of lezer packages depended on.

## 0.13.0 (2020-12-04)

## 0.12.0 (2020-10-23)

### Breaking changes

Adjust to changed serialized parser format.

## 0.11.1 (2020-09-26)

### Bug fixes

Fix lezer depencency versions

## 0.11.0 (2020-09-26)

### Breaking changes

Follow change in serialized parser format.

## 0.10.1 (2020-09-02)

### Bug fixes

Fix a conflicting pair of tokens that the generator previously didn't catch.

## 0.10.0 (2020-08-07)

### Breaking changes

Upgrade to 0.10 parser serialization

## 0.9.0 (2020-06-08)

### Breaking changes

Upgrade to 0.9 parser serialization

## 0.8.3 (2020-04-09)

### Bug fixes

Regenerate parser with a fix in lezer-generator so that the top node prop is properly assigned.

## 0.8.2 (2020-04-01)

### Bug fixes

Make the package load as an ES module on node

## 0.8.1 (2020-02-28)

### New features

Provide an ES module file.

## 0.8.0 (2020-02-03)

### New features

Follow 0.8.0 release of the library.

## 0.7.0 (2020-01-20)

### Breaking changes

Use the lezer 0.7.0 parser format.

## 0.5.2 (2020-01-15)

### Bug fixes

Regenerate with lezer-generator 0.5.2 to avoid cyclic forced reductions.

## 0.5.1 (2019-10-22)

### Bug fixes

Fix top prop missing from build output.

## 0.5.0 (2019-10-22)

### Breaking changes

Move from `lang` to `top` prop on document node.

## 0.4.0 (2019-09-10)

### Breaking changes

Adjust to 0.4.0 parse table format.

## 0.3.0 (2019-08-22)

### New features

Go back to node names, add props, follow changes in grammar syntax.

## 0.2.0 (2019-08-02)

### New Features

First documented release.
